@@ -11,6 +11,8 @@ from ..types import (
     GetResponse,
     InvokeRequest,
     InvokeResponse,
+    GetScriptCommandRequest,
+    GetScriptCommandResponse,
     InvokeScriptRequest,
     InvokeScriptResponse,
     DeleteRequest,
@@ -47,6 +49,12 @@ class BaseProvider(metaclass=abc.ABCMeta):
     def load(self, request: LoadRequest) -> LoadResponse:
         ...
 
+    @abc.abstractmethod
+    def getScriptCommand(
+        self, request: GetScriptCommandRequest
+    ) -> GetScriptCommandResponse:
+        ...
+
     @abc.abstractmethod
     def invokeBinScript(self, request: InvokeScriptRequest) -> InvokeScriptResponse:
         ...
