@@ -41,6 +41,8 @@ from ..types import (
     GetResponse,
     InvokeRequest,
     InvokeResponse,
+    GetScriptCommandRequest,
+    GetScriptCommandResponse,
     InvokeScriptRequest,
     InvokeScriptResponse,
     SetRequest,
@@ -62,7 +64,7 @@ from ..types import (
     CompleteRequest,
     CompleteResponse,
 )
-from ...errors import JSIIError, JavaScriptError
+from ...errors import ErrorType, JSIIError, JavaScriptError
 
 
 @attr.s(auto_attribs=True, frozen=True, slots=True)
@@ -83,10 +85,11 @@ class _OkayResponse:
 
 
 @attr.s(auto_attribs=True, frozen=True, slots=True)
-class _ErrorRespose:
+class _ErrorResponse:
 
     error: str
     stack: str
+    name: str
 
 
 @attr.s(auto_attribs=True, frozen=True, slots=True)
@@ -101,7 +104,7 @@ class _CompleteRequest:
     complete: CompleteRequest
 
 
-_ProcessResponse = Union[_OkayResponse, _ErrorRespose, _CallbackResponse]
+_ProcessResponse = Union[_OkayResponse, _ErrorResponse, _CallbackResponse]
 
 
 def _with_api_key(api_name, asdict):
@@ -159,6 +162,12 @@ class _NodeProcess:
             LoadRequest,
             _with_api_key("load", self._serializer.unstructure_attrs_asdict),
         )
+        self._serializer.register_unstructure_hook(
+            GetScriptCommandRequest,
+            _with_api_key(
+                "getBinScriptCommand", self._serializer.unstructure_attrs_asdict
+            ),
+        )
         self._serializer.register_unstructure_hook(
             InvokeScriptRequest,
             _with_api_key("invokeBinScript", self._serializer.unstructure_attrs_asdict),
@@ -326,7 +335,9 @@ class _NodeProcess:
         elif isinstance(resp, _CallbackResponse):
             return resp.callback
         else:
-            raise JSIIError(resp.error) from JavaScriptError(resp.stack)
+            if resp.name == ErrorType.JSII_FAULT.value:
+                raise JSIIError(resp.error) from JavaScriptError(resp.stack)
+            raise RuntimeError(resp.error) from JavaScriptError(resp.stack)
 
 
 class ProcessProvider(BaseProvider):
@@ -340,6 +351,11 @@ class ProcessProvider(BaseProvider):
     def load(self, request: LoadRequest) -> LoadResponse:
         return self._process.send(request, LoadResponse)
 
+    def getScriptCommand(
+        self, request: GetScriptCommandRequest
+    ) -> GetScriptCommandResponse:
+        return self._process.send(request, GetScriptCommandResponse)
+
     def invokeBinScript(self, request: InvokeScriptRequest) -> InvokeScriptResponse:
         return self._process.send(request, InvokeScriptResponse)
 
