@@ -1,15 +1,26 @@
 import abc
 import os
+import sys
+import subprocess
 
 import attr
 
-from typing import cast, Any, Callable, List, Optional, Mapping, Type, TypeVar
+from typing import (
+    Any,
+    Callable,
+    cast,
+    List,
+    Mapping,
+    Optional,
+    Sequence,
+    Type,
+    TypeVar,
+)
 
 from . import _reference_map
 from ._compat import importlib_resources
 from ._kernel import Kernel
 from .python import _ClassPropertyMeta
-from ._kernel.types import ObjRef
 
 
 # Yea, a global here is kind of gross, however, there's not really a better way of
@@ -47,10 +58,24 @@ class JSIIAssembly:
 
     @classmethod
     def invokeBinScript(
-        cls, pkgname: str, script: str, *args: str, _kernel=kernel
-    ) -> None:
-        response = _kernel.invokeBinScript(pkgname, script, args)
-        print(response.stdout)
+        cls,
+        pkgname: str,
+        script: str,
+        args: Optional[Sequence[str]] = None,
+        _kernel=kernel,
+    ) -> int:
+        if args is None:
+            args = []
+
+        response = _kernel.getBinScriptCommand(pkgname, script, args)
+
+        result = subprocess.run(
+            " ".join([response.command, *response.args]),
+            encoding="utf-8",
+            shell=True,
+            env=response.env,
+        )
+        return result.returncode
 
 
 class JSIIMeta(_ClassPropertyMeta, type):
